@@ -1,4 +1,7 @@
+mod callback;
+mod link;
 mod list;
+mod ptr;
 mod text;
 mod util;
 mod value;
@@ -9,15 +12,17 @@ pub mod traits;
 
 pub type ShouldRender = bool;
 
-pub use list::{IterWrapper, RenderedList};
-pub use text::RenderedText;
+pub use link::Link;
+pub use list::{BuiltList, IterWrapper};
+pub use text::BuiltText;
 pub use traits::{Component, Html, Mountable, Update};
 
 pub mod prelude {
-    pub use super::{html, Component, Html, Mountable, ShouldRender, Update};
+    pub use super::{html, Component, Html, Link, Mountable, ShouldRender, Update};
 }
 
 pub use kobold_macros::html;
+pub use wasm_bindgen::JsValue;
 pub use web_sys::Node;
 
 pub mod reexport {
@@ -25,15 +30,23 @@ pub mod reexport {
     pub use web_sys;
 }
 
+pub fn start(html: impl Html) {
+    use std::mem::ManuallyDrop;
+
+    let built = ManuallyDrop::new(html.build());
+
+    util::__kobold_start(built.js());
+}
+
 mod empty {
     use crate::prelude::*;
     use crate::util;
     use web_sys::Node;
 
     impl Html for () {
-        type Rendered = EmptyNode;
+        type Built = EmptyNode;
 
-        fn render(self) -> EmptyNode {
+        fn build(self) -> EmptyNode {
             EmptyNode(util::__kobold_empty_node())
         }
     }
@@ -41,7 +54,7 @@ mod empty {
     pub struct EmptyNode(Node);
 
     impl Mountable for EmptyNode {
-        fn node(&self) -> &Node {
+        fn js(&self) -> &wasm_bindgen::JsValue {
             &self.0
         }
     }
