@@ -3,6 +3,11 @@ use web_sys::Node;
 
 #[wasm_bindgen(module = "/js/util.js")]
 extern "C" {
+    pub(crate) fn __kobold_start(node: &JsValue);
+
+    pub(crate) fn __kobold_mount(parent: &Node, child: &JsValue);
+    pub(crate) fn __kobold_unmount(parent: &Node, child: &JsValue);
+
     pub(crate) fn __kobold_empty_node() -> Node;
 
     pub(crate) fn __kobold_text_node(t: &str) -> Node;
